@@ -66,31 +66,6 @@ class AbstractNode(DrbNode, abc.ABC):
             return DrbNodeList(children)
         raise TypeError(f"{type(item)} type not supported.")
 
-    def __truediv__(self, child):
-        try:
-            if isinstance(child, str):
-                return self.__resolve_result(self._get_named_child(child))
-            elif isinstance(child, tuple):
-                if len(child) == 2:
-                    name, other = child
-                    if isinstance(other, str):
-                        return self.__resolve_result(
-                            self._get_named_child(*child))
-                    elif isinstance(other, (int, slice)):
-                        return self.__resolve_result(
-                            self._get_named_child(name, occurrence=other))
-                if len(child) == 3:
-                    return self.__resolve_result(
-                        self._get_named_child(*child))
-        except (DrbException, IndexError, TypeError) as ex:
-            raise KeyError(f'Invalid key: {child}') from ex
-
-        if isinstance(child, Predicate):
-            children = [n for n in self.children if child.matches(n)]
-            return DrbNodeList(children)
-
-        raise DrbNotImplementationException(f"{type(child)} type not managed.")
-
     def _get_named_child(self, name: str, namespace_uri: str = None,
                          occurrence: Union[int, slice] = 0) -> \
             Union[DrbNode, List[DrbNode]]:
