@@ -1,6 +1,6 @@
 from .factory import DrbFactory, FactoryLoader
 from .signature import Signature
-from .item_class import ItemClass, ItemClassType
+from .item_class import ItemClass, ItemClassType, ItemClassLoader
 from .factory_resolver import DrbFactoryResolver
 
 __all__ = [
@@ -9,5 +9,6 @@ __all__ = [
     'Signature',
     'ItemClass',
     'ItemClassType',
+    'ItemClassLoader',
     'DrbFactoryResolver',
 ]
