@@ -1,18 +1,13 @@
 import os
-import importlib
 import logging
-import uuid
-from importlib.metadata import entry_points
 
-import yaml
-from jsonschema.exceptions import ValidationError
 from urllib.parse import urlparse
-from typing import Dict, List, Optional, Tuple, Union
+from typing import List, Optional, Tuple, Union
 
 from .factory import DrbFactory
-from .item_class import ItemClass, ItemClassType
+from .item_class import ItemClass, ItemClassType, ItemClassLoader
 from ..node import DrbNode
-from ..exceptions import DrbException, DrbFactoryException
+from ..exceptions import DrbFactoryException
 from ..utils.url_node import UrlNode
 
 
@@ -26,54 +21,6 @@ def is_remote_url(parsed_path):
     return parsed_path.scheme != '' and parsed_path.scheme != 'file'
 
 
-def _load_drb_item_classes() -> Dict[uuid.UUID, ItemClass]:
-    """
-    Loads item classes defined in the Python context
-    """
-    entry_point_group = 'drb.impl'
-    result = {}
-
-    eps = entry_points()
-    if entry_point_group not in eps:
-        logger.warning('No DRB topic or implementation found')
-        return result
-
-    for ep in eps[entry_point_group]:
-        # load module
-        try:
-            module = importlib.import_module(ep.value)
-        except ModuleNotFoundError as ex:
-            logger.warning(f'Invalid entry point {ep.name}: {ex.msg}')
-            continue
-
-        # check item class description file
-        try:
-            path = os.path.join(os.path.dirname(module.__file__), 'cortex.yml')
-            ItemClass.validate(path)
-        except (FileNotFoundError, ValidationError) as ex:
-            logger.warning(
-                f'Invalid item class description(s) from {ep.name}: {ex.msg}')
-            continue
-
-        # load deserialize item classes
-        with open(path) as file:
-            data = yaml.safe_load_all(file)
-            for ic_data in data:
-                try:
-                    ic = ItemClass(ic_data)
-                except (KeyError, DrbException):
-                    logger.warning(f'Failed to load item class: {ic_data}')
-                    continue
-
-                if ic.id in result:
-                    logger.warning(
-                        f'Item class definition conflict: id ({ic.id}) used '
-                        f'by {result[ic.id].label} and {ic.label}')
-                else:
-                    result[ic.id] = ic
-    return result
-
-
 class DrbFactoryResolver(DrbFactory):
     """ The factory resolver
 
@@ -82,7 +29,8 @@ class DrbFactoryResolver(DrbFactory):
     """
 
     __instance = None
-    __item_classes: Dict[uuid.UUID, ItemClass] = None
+    __item_classes = None
+    __overridden: List[ItemClass] = None
     __protocols: List[ItemClass] = None
     __containers: List[ItemClass] = None
     __highest_containers: List[ItemClass] = None
@@ -91,11 +39,14 @@ class DrbFactoryResolver(DrbFactory):
     def __new__(cls, *args, **kwargs):
         if cls.__instance is None:
             cls.__instance = super(DrbFactoryResolver, cls).__new__(cls)
-            cls.__item_classes = _load_drb_item_classes()
+            cls.__item_classes = ItemClassLoader().get_all_item_classes()
+            cls.__overridden = []
             cls.__protocols = []
             cls.__containers = []
             cls.__formats = []
-            for ic in cls.__item_classes.values():
+            for ic in cls.__item_classes:
+                if ic.is_override_super_class():
+                    cls.__overridden.append(ic)
                 if ItemClassType.PROTOCOL == ic.category:
                     cls.__protocols.append(ic)
                 elif ItemClassType.CONTAINER == ic.category:
@@ -128,7 +79,7 @@ class DrbFactoryResolver(DrbFactory):
                      ``None`` if no protocol item class is found.
         """
         for protocol in self.__protocols:
-            if protocol.signature.matches(node):
+            if protocol.matches(node):
                 return protocol
         return None
 
@@ -142,14 +93,14 @@ class DrbFactoryResolver(DrbFactory):
             ItemClass: A item class matching the given node, otherwise ``None``
         """
         for s in self.__highest_containers:
-            if s.signature.matches(node):
-                return self.__finest_container(node, s)
+            if s.matches(node):
+                return self.__finest_item_class(node, s)
         return None
 
-    def __finest_container(self, node: DrbNode, finest: ItemClass) \
+    def __finest_item_class(self, node: DrbNode, finest: ItemClass) \
             -> ItemClass:
         """
-        Retrieves the finest container item class associated to the given node.
+        Retrieves the finest item class associated to the given node.
 
         Parameters:
             node (DrbNode): node which need to be resolved
@@ -158,11 +109,11 @@ class DrbFactoryResolver(DrbFactory):
         Returns:
             ItemClass: the finest item class matching the given node
         """
-        children_classes = [x for x in self.__containers
-                            if x.parent_class_id == finest.id]
-        for item_class in children_classes:
-            if item_class.signature.matches(node):
-                return self.__finest_container(node, item_class)
+        subclasses = [x for x in self.__item_classes
+                      if x.parent_class_id == finest.id]
+        for item_class in subclasses:
+            if item_class.matches(node):
+                return self.__finest_item_class(node, item_class)
         return finest
 
     def __retrieve_formatting(self, node) -> Optional[ItemClass]:
@@ -176,7 +127,7 @@ class DrbFactoryResolver(DrbFactory):
                        otherwise ``None``
         """
         for item_class in self.__formats:
-            if item_class.signature.matches(node):
+            if item_class.matches(node):
                 return item_class
         return None
 
@@ -226,20 +177,15 @@ class DrbFactoryResolver(DrbFactory):
                 curl = os.path.join(curl, path.pop(0))
             return self.__create_from_url(url, curl, path)
 
-    def resolve(self, source: Union[str, DrbNode]) \
-            -> Tuple[ItemClass, Optional[DrbNode]]:
-        """
-        Retrieves the item class related to the given source.
+    def _resolve_overridden(self, source: DrbNode) -> \
+            Optional[Tuple[ItemClass, Optional[DrbNode]]]:
+        for ic in self.__overridden:
+            if ic.matches(source):
+                return self.__finest_item_class(source, ic), source
+        return None
 
-        Parameters:
-            source: source to be resolved
-        Returns:
-            tuple: A tuple containing an ItemClass corresponding to the given
-                   source and the last DrbNode allowing to resolve the given
-                   source (maybe to ``None``)
-        Raises:
-            DrbFactoryException: if the given source cannot be resolved.
-        """
+    def _basic_resolve(self, source: DrbNode) -> \
+            Tuple[ItemClass, Optional[DrbNode]]:
         if isinstance(source, str):
             node = UrlNode(source)
         else:
@@ -261,7 +207,7 @@ class DrbFactoryResolver(DrbFactory):
 
         formatting = self.__retrieve_formatting(node)
         if formatting is not None:
-            return formatting, node
+            return self.__finest_item_class(node, formatting), node
 
         if container is None:
             if protocol is None:
@@ -272,6 +218,30 @@ class DrbFactoryResolver(DrbFactory):
             return container, old_node
         return container, node
 
+    def resolve(self, source: Union[str, DrbNode]) \
+            -> Tuple[ItemClass, Optional[DrbNode]]:
+        """
+        Retrieves the item class related to the given source.
+
+        Parameters:
+            source: source to be resolved
+        Returns:
+            tuple: A tuple containing an ItemClass corresponding to the given
+                   source and the last DrbNode allowing to resolve the given
+                   source (maybe to ``None``)
+        Raises:
+            DrbFactoryException: if the given source cannot be resolved.
+        """
+        if isinstance(source, str):
+            node = UrlNode(source)
+        else:
+            node = source
+
+        result = self._resolve_overridden(node)
+        if result is not None:
+            return result
+        return self._basic_resolve(node)
+
     def create(self, source: Union[DrbNode, str]) -> DrbNode:
         if isinstance(source, str):
             return self.__create_from_url(source)
