@@ -186,62 +186,6 @@ class DrbNode(DrbItem, NodeImpl, abc.ABC):
         """
         raise NotImplementedError
 
-    @abc.abstractmethod
-    def __truediv__(self, child):
-        """
-        Div operator setup to manage access to children list.
-        The truediv operator is redefined here to manage path navigation as
-        posix style representation. It allows access to the children by their
-        names following these rules:
-
-        * ``str``: the first child node with the item as name is retrieved
-          from its children
-
-        * ``tuple``: the following tuple must be supported per each node
-          implementation:
-
-            * (name: ``str``, namespace: ``str``): retrieves first child by is
-              name and namespace_uri.
-
-            * (name: ``str``, item: ``int`` | ``slice``): retrieves a child or
-              a children interval having a specific name.
-
-            * (name: ``str``, namespace: ``str``, item: ``int`` | ``slice``):
-              retrieves a child or a children interval having a specific name
-              and namespace_uri
-
-        * ``Predicate``: children nodes matching this predicate are
-          returned, may return an empty list
-
-        Returns:
-            DrbNode or List[DrbNode]: expected child node(s) according to the
-            case
-        Raises:
-            DrbException: if no child is found, except for ``Predicate`` case
-                          where an empty may return.
-        Examples:
-
-        .. code-block:: python
-
-            # first child by its name
-            child = node / 'child_name' # == node / ('child_name', 0)
-            # third child named name_child
-            child = node / ('child_name', 2)
-            # children interval of child named child_name (first 2 children)
-            children = node / ('child_name', slice(None, 2))
-
-            # first child named child_name and having as namespace ns
-            child = node / ('child_name', 'ns')
-            # last child named child_name and having as namespace ns
-            child = node / ('child_name', 'ns', -1)
-            # all children named child_name and having as namespace ns
-            child = node / ('child_name', 'ns', slice(None, None))
-
-            # get children using a Predicate
-            children = node / MyPredicate()
-        """
-        raise NotImplementedError
-
     @property
     def namespace_aware(self) -> bool:
         """
